==> diffoscope-146-1-x86_64.pkg.tar.zst: usr/lib/python3.8/site-packages/diffoscope/comparators/pcap.py <==
# -*- coding: utf-8 -*-
#
# diffoscope: in-depth comparison of files, archives, and directories
#
# Copyright © 2017-2019 Chris Lamb <lamby@debian.org>
#
# diffoscope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# diffoscope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with diffoscope.  If not, see <https://www.gnu.org/licenses/>.

import re

from diffoscope.tools import tool_required
from diffoscope.difference import Difference

from .utils.file import File
from .utils.command import Command


class Tcpdump(Command):
    @tool_required("tcpdump")
    def cmdline(self):
        return (
            "tcpdump",
            "-X",  # Print data and link level header in hex and ASCII
            "-nn",  # Don't resolve host addresses, etc.
            "-ttttt",  # Print delta from previous line
            "-r",
            self.path,
        )


class PcapFile(File):
    DESCRIPTION = "tcpdump capture files (.pcap)"
    FILE_TYPE_RE = re.compile(r"^(tcpdump|pcap) capture file\b")

    def compare_details(self, other, source=None):
        return [
            Difference.from_command(
                Tcpdump, self.path, other.path, source="tcpdump"
            )
        ]

==> diffoscope-161-3-x86_64.pkg.tar.zst: usr/lib/python3.9/site-packages/diffoscope/comparators/pcap.py <==
# -*- coding: utf-8 -*-
#
# diffoscope: in-depth comparison of files, archives, and directories
#
# Copyright © 2017-2019 Chris Lamb <lamby@debian.org>
#
# diffoscope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# diffoscope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with diffoscope.  If not, see <https://www.gnu.org/licenses/>.

import re

from diffoscope.tools import tool_required
from diffoscope.difference import Difference

from .utils.file import File
from .utils.command import Command


class Tcpdump(Command):
    @tool_required("tcpdump")
    def cmdline(self):
        return (
            "tcpdump",
            "-X",  # Print data and link level header in hex and ASCII
            "-nn",  # Don't resolve host addresses, etc.
            "-ttttt",  # Print delta from previous line
            "-r",
            self.path,
        )


class PcapFile(File):
    DESCRIPTION = "tcpdump capture files (.pcap)"
    FILE_TYPE_RE = re.compile(r"^(tcpdump|pcap) capture file\b")

    def compare_details(self, other, source=None):
        return [
            Difference.from_operation(
                Tcpdump, self.path, other.path, source="tcpdump"
            )
        ]
